data_bird.RdThis dataset was derived from NEON data portal with data product ID 'DP1.10003.001'. Details about this data product can be found at https://data.neonscience.org/data-products/DP1.10003.001.
data_birdA data frame (also a tibble) with the following columns:
location_id: Location id.
siteID: NEON site code.
plotID: Plot identifier (NEON site code_XXX).
pointID: Identifier for a point location.
unique_sample_id: Identity of unique samples (equals eventID).
observation_datetime: Observation date and time.
taxon_id: Accepted species code, based on one or more sources.
taxon_name: Scientific name, associated with the taxonID. This is the name
of the lowest level taxonomic rank that can be determined.
taxon_rank: The lowest level taxonomic rank that can be determined for the individual or specimen.
variable_name: The variable name(s) represented by the value column.
value: Cluster size (count of individuals observed); NA for zero-bird points.
unit: Unit of the values in the value column.
pointCountMinute: The minute of sampling within the point count period.
targetTaxaPresent: Indicator of whether the sample contained individuals of the target taxa.
nativeStatusCode: The process by which the taxon became established in the location.
'A': Presumed absent; 'N': Native; 'I': Introduced; 'UNK': Status unknown.
observerDistance: Radial distance between the observer and the individual(s) being observed (meter).
detectionMethod: How the individual(s) was (were) first detected by the observer.
visualConfirmation: Whether the individual(s) was (were) seen after the initial detection.
sexOrAge: Sex of individual if detectable, age of individual if individual cannot be sexed.
release: Version of data release by NEON.
startCloudCoverPercentage: Observer estimate of percent cloud cover at start of sampling.
endCloudCoverPercentage: Observer estimate of percent cloud cover at end of sampling.
startRH: Relative humidity as measured by handheld weather meter at the start of sampling.
endRH: Relative humidity as measured by handheld weather meter at the end of sampling.
observedHabitat: Observer assessment of dominant habitat at the sampling point at sampling time.
observedAirTemp: The air temperature (Celsius) measured with a handheld weather meter.
kmPerHourObservedWindSpeed: The average wind speed measured with a handheld weather meter, in kilometers per hour.
samplingProtocolVersion: The NEON document number and version where detailed information regarding the sampling method used is available; format 'NEON.DOC.######vX'.
remarks: Remarks of record.
clusterCode: Alphabetic code (A-Z) linking clusters of individuals of the same species spanning multiple records.
latitude: The geographic latitude (in decimal degrees, WGS84) of the geographic center of the reference area.
longitude: The geographic longitude (in decimal degrees, WGS84) of the geographic center of the reference area.
elevation: Elevation (in meters) above sea level.
nlcdClass: National Land Cover Database Vegetation Type Name.
plotType: NEON plot type in which sampling occurred: tower, distributed or gradient.
To clean the data, we:
Filtered brd_perpoint to samplingImpractical == "OK" to retain only surveyed points.
Left-joined downward from point survey records to brd_countdata to preserve zero-bird survey points.
Retained valid cluster size values and zero-bird survey rows; value = cluster size (count of individuals).
unique_sample_id = eventID.
Details of locations (e.g. latitude/longitude coordinates can be found in neon_location). The sampling protocol has evolved over time, so users are advised to check whether the samplingProtocolVersion fits their data requirements and subset as necessary.